weeWX: Installation using zypper

# SUSE repository for weeWX

## Tell the system to trust weewx.com

    sudo rpm --import http://weewx.com/keys.html

## Configure

For python3 (suse 15):

    curl -s http://weewx.com/suse/weewx-suse15.repo | sudo tee /etc/zypp/repos.d/weewx.repo

For python2 (suse 12):

    curl -s http://weewx.com/suse/weewx-suse12.repo | sudo tee /etc/zypp/repos.d/weewx.repo

## Install weeWX

    sudo zypper install weewx

## Update weeWX

    sudo zypper update weewx